@@ -2,7 +2,7 @@
  * @Author: aran.hu 
  * @Date: 2017-04-14 14:29:04 
  * @Last Modified by: aran.hu
- * @Last Modified time: 2017-06-30 10:55:54
+ * @Last Modified time: 2017-06-30 17:58:24
  */
 
 import React, { Component, PropTypes } from 'react';
@@ -44,8 +44,8 @@ export const RefreshText = {
 }
 
 export const FooterText = {
-  pushToRefresh: 'pull to refresh',
-  loading: 'refreshing...'
+  pushToRefresh: 'load more',
+  loading: 'loading...'
 }
 
 export const ViewType = {
@@ -63,6 +63,7 @@ export default class FlatListTest extends Component {
     customRefreshView: PropTypes.func,
     isRefresh: PropTypes.bool,
     onRefreshFun: PropTypes.func,
+    onEndReached: PropTypes.func,
     viewType: PropTypes.oneOf(['ListView', 'ScrollView']) 
   };
   
@@ -153,7 +154,8 @@ export default class FlatListTest extends Component {
         this.beforeRefreshState = RefreshState.pullToRefresh
         this.updateRefreshViewState(RefreshState.refreshdown)
       } else {
-        this.updateRefreshViewState(RefreshState.pullToRefresh)
+        // 意欲何为?
+        // this.updateRefreshViewState(RefreshState.pullToRefresh)
       }
     }
   }
@@ -168,7 +170,9 @@ export default class FlatListTest extends Component {
               toValue: -this.headerHeight,
               duration: 200,
               easing: Easing.linear
-          }).start()
+          }).start(()=>{
+            this.updateItemRenderState()
+          })
         })
         break;
       case RefreshState.releaseToRefresh:
@@ -190,6 +194,7 @@ export default class FlatListTest extends Component {
           // This delay is shown in order to show the refresh time to complete the refresh
           this.setState({toRenderItem: false}) 
           this.t = setTimeout(() => {
+            // 当刷新完成时，先回到初始状态保持100%, 然后在更新组件状态
             Animated.timing(
               this._marginTop,
               {
@@ -201,16 +206,24 @@ export default class FlatListTest extends Component {
             })
           }, 500)
         })
+        break
       default:
         
     }
   }
 
+  // 滑动列表结束后，设置item可以render， 用来接收新的state
+  updateItemRenderState() {
+    if(!this.state.toRenderItem) {
+      this.setState({toRenderItem: true})
+    }
+  }
+
   _onSwipe = (movement) => {
     /**
      * If you are in the refresh or refresh the completion of the state will not trigger the refresh
      */
-    this.setState({toRenderItem: false})
+    // this.setState({toRenderItem: false})
     if(this.state.refreshState >= RefreshState.refreshing) return
     this._scrollEndY = movement
     this._marginTop.setValue( movement - this.headerHeight )
@@ -226,6 +239,7 @@ export default class FlatListTest extends Component {
     if(this.state.refreshState >= RefreshState.refreshing) return
     if(this._scrollEndY >= this.headerHeight) {
       const { onRefreshFun } = this.props
+      this.setRefreshState(true)
       onRefreshFun?onRefreshFun(): this._onRefreshFun()
     } else {
       //下拉距离不够自动收回
@@ -235,17 +249,32 @@ export default class FlatListTest extends Component {
           toValue: -this.headerHeight,
           duration: 200,
           easing: Easing.linear
-      }).start()
+      }).start(()=>{
+        this.updateItemRenderState()
+      })
     }
   }
 
   _onEndReached = () => {
+    const { onEndReached } = this.props
+    if(onEndReached) {
+      return onEndReached()
+    }
     this.setState({footerMsg: 'loading'})
     this.timer2 = setTimeout(() => {
       this.setState({footerMsg: 'load more'})
     }, 1000)
   }
 
+  _onTouchStart = () => {
+    this.setState({toRenderItem: false})
+  } 
+  _onMomentumScrollEnd = () => {
+    this.setState({toRenderItem: true})
+  }
+  _onScrollEndDrag = () => {
+    this.setState({toRenderItem: true})
+  }
   _renderItem = (item) => {
     return <Item {...this.props} item={item} toRenderItem={this.state.toRenderItem} />
   }
@@ -367,6 +396,8 @@ export default class FlatListTest extends Component {
               renderItem={this._renderItem}
               keyExtractor={(v,i)=>i}
               ListHeaderComponent={this.customRefreshView}
+              onTouchStart={this._onTouchStart}
+              onMomentumScrollEnd={this._onMomentumScrollEnd}
               style={[{...this.props.style},
               {marginTop: this._marginTop.interpolate({
                 inputRange: [-this.headerHeight, 0, 500],
@@ -383,7 +414,10 @@ export default class FlatListTest extends Component {
               ListHeaderComponent={this.customRefreshView}
               ListFooterComponent={this._ListFooterComponent}
               onEndReached={this._onEndReached} 
-              onEndReachedThreshold={0}
+              onEndReachedThreshold={10}
+              onTouchStart={this._onTouchStart}
+              onScrollEndDrag={this._onScrollEndDrag}
+              onMomentumScrollEnd={this._onMomentumScrollEnd}
               style={[{...this.props.style},
               {marginTop: this._marginTop.interpolate({
                 inputRange: [-this.headerHeight, 0, 500],
@@ -394,6 +428,4 @@ export default class FlatListTest extends Component {
       </AndroidSwipeRefreshLayout>
     );
   }
-}
-
-
+}
\ No newline at end of file
