@@ -2,7 +2,7 @@
  * @Author: aran.hu
  * @Date: 2017-04-14 14:29:15
  * @Last Modified by: aran.hu
- * @Last Modified time: 2017-06-30 10:56:30
+ * @Last Modified time: 2017-06-30 15:10:23
  */
 
 
@@ -59,6 +59,7 @@ export default class RefreshFlatList extends Component {
   static propTypes = {
     customRefreshView: PropTypes.func,
     onRefreshFun: PropTypes.func,
+    onEndReached: PropTypes.func,
     isRefresh: PropTypes.bool,
     viewType: PropTypes.oneOf(['ListView', 'ScrollView'])
   };
@@ -163,7 +164,8 @@ export default class RefreshFlatList extends Component {
         this.beforeRefreshState = RefreshState.pullToRefresh
         this.updateRefreshViewState(RefreshState.refreshdown)
       } else {
-        this.updateRefreshViewState(RefreshState.pullToRefresh)
+        //?
+        // this.updateRefreshViewState(RefreshState.pullToRefresh)
       }
     }
   }
@@ -184,7 +186,6 @@ export default class RefreshFlatList extends Component {
       case RefreshState.refreshdown:
         this.setState({refreshState: RefreshState.refreshdown, refreshText: RefreshText.refreshdown, percent: 100, toRenderItem: true}, () => {
           // This delay is shown in order to show the refresh time to complete the refresh
-          this.setState({toRenderItem: false}) 
           this.t = setTimeout(() => {
             this._flatList.scrollToOffset({animated:true, offset: 0})
             this.tt = setTimeout(() => {
@@ -198,6 +199,10 @@ export default class RefreshFlatList extends Component {
   }
 
   _onEndReached = () => {
+    const { onEndReached } = this.props
+    if(onEndReached) {
+      return onEndReached()
+    }
     this.setState({footerMsg: 'loading'})
     this.timer2 = setTimeout(() => {
       this.setState({footerMsg: 'load more'})
@@ -207,6 +212,7 @@ export default class RefreshFlatList extends Component {
   _onScroll = (e) => {
     let { y } = e.nativeEvent.contentOffset
     this._scrollEndY = y
+    if(this._scrollEndY == 0) this.setState({toRenderItem: true})
     if(!this.isOnMove && -y >= 0){
       //刷新状态下，上推列表依percent然显示100%
       let p = parseInt(( -y / (this.headerHeight)) * 100)
@@ -222,15 +228,6 @@ export default class RefreshFlatList extends Component {
 
   onMove(e, g) {
     this.mTop = g.dy
-
-    // if(!this.key && this._scrollEndY < -this.headerHeight) {
-    //   this.key = true
-    //   this.updateRefreshViewState(RefreshState.releaseToRefresh)
-    // } else if(this.key && this._scrollEndY > -this.headerHeight) {
-    //   this.key = false
-    //   this.updateRefreshViewState(RefreshState.pullToRefresh)
-    // }
-    
     if(g.dy >= 0){
       let p = parseInt(( g.dy / (2 * this.headerHeight)) * 100)
       p = p > 100? 100: p
@@ -247,6 +244,7 @@ export default class RefreshFlatList extends Component {
     this.isOnMove = false
     if(this._scrollEndY < -this.headerHeight) {
       const { onRefreshFun } = this.props
+      this.setRefreshState(true)
       onRefreshFun?onRefreshFun(): this._onRefreshFun()
     }
   }
@@ -259,18 +257,6 @@ export default class RefreshFlatList extends Component {
     return <Item {...this.props} item={item} toRenderItem={this.state.toRenderItem}/>
   }
 
-  _renderItemScrollView = () => {
-    const { renderItem } = this.props
-    if(renderItem) {
-      return renderItem()
-    }
-    return (
-      <View style={{width: width, height: 100}} >
-        <Text> {'This is a ScrollView'} </Text>
-      </View>
-    )
-  }
-
   customRefreshView = () => {
     const { customRefreshView } = this.props
     const { refreshState, refreshText, percent} = this.state
@@ -382,7 +368,7 @@ export default class RefreshFlatList extends Component {
           {...this.props}
           onScroll={this._onScroll}
           data={['1']}
-          renderItem={this._renderItemScrollView}
+          renderItem={this._renderItem}
           keyExtractor={(v,i)=>i}
           ListHeaderComponent={this.customRefreshView}
           style={[{...this.props.style},{marginTop: -this.headerHeight}]}
@@ -407,4 +393,4 @@ export default class RefreshFlatList extends Component {
       );
     }
   }
-}
+}
\ No newline at end of file
